Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(220)

Unified Diff: content/browser/speech/speech_recognizer_impl.h

Issue 9972008: Refactoring of chrome speech recognition architecture (CL1.6) (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebased from master. Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/speech/speech_recognizer_impl.h
diff --git a/content/browser/speech/speech_recognizer_impl.h b/content/browser/speech/speech_recognizer_impl.h
index a2cce74f077a101dd757f7f4225a65a6bd6ac53c..5b37d61a9d6ff9685efe0ccc12eea3a80ea8547e 100644
--- a/content/browser/speech/speech_recognizer_impl.h
+++ b/content/browser/speech/speech_recognizer_impl.h
@@ -18,11 +18,9 @@
namespace content {
class SpeechRecognitionEventListener;
-struct SpeechRecognitionResult;
}
namespace media {
-class AudioInputController;
class AudioManager;
}
@@ -32,7 +30,7 @@ namespace speech {
// /content/public/browser/speech_recognizer.h interface since this class should
// not be visible outside (currently we need it for speech input extension API).
// Handles speech recognition for a session (identified by |caller_id|), taking
// care of audio capture, silence detection/endpointer and interaction with the
// SpeechRecognitionEngine.
class CONTENT_EXPORT SpeechRecognizerImpl
@@ -48,7 +46,7 @@ class CONTENT_EXPORT SpeechRecognizerImpl
SpeechRecognizerImpl(
content::SpeechRecognitionEventListener* listener,
- int caller_id,
+ int session_id,
SpeechRecognitionEngine* engine);
virtual ~SpeechRecognizerImpl();
@@ -152,7 +150,7 @@ class CONTENT_EXPORT SpeechRecognizerImpl
scoped_ptr<SpeechRecognitionEngine> recognition_engine_;
Endpointer endpointer_;
scoped_refptr<media::AudioInputController> audio_controller_;
- int caller_id_;
+ int session_id_;
int num_samples_recorded_;
float audio_level_;
bool is_dispatching_event_;
@@ -32,7 +30,7 @@ namespace speech {
// /content/public/browser/speech_recognizer.h interface since this class should
// not be visible outside (currently we need it for speech input extension API).
-// Handles speech recognition for a session (identified by |caller_id|), taking
+// Handles speech recognition for a session (identified by |session_id|), taking
// care of audio capture, silence detection/endpointer and interaction with the
// SpeechRecognitionEngine.
« no previous file with comments | « content/browser/speech/speech_recognition_manager_impl.cc ('k') | content/browser/speech/speech_recognizer_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698